Update identifiers and paths to the new ART APEX.

Test: atest -p frameworks/native/cmds/installd
Test: ATP asit/dexoptota/self_full on Forrest:
  https://android-build.googleplex.com/builds/forrest/run/L53500000356596506
Bug: 135753770
Exempt-From-Owner-Approval: Approved internally
Change-Id: I11000a8cc95085bb0144f858b4f3968e5aceac36
Merged-In: I11000a8cc95085bb0144f858b4f3968e5aceac36
diff --git a/cmds/installd/dexopt.h b/cmds/installd/dexopt.h
index a8c48c5..ef739ba 100644
--- a/cmds/installd/dexopt.h
+++ b/cmds/installd/dexopt.h
@@ -32,15 +32,15 @@
 static constexpr int DEX2OAT_FOR_BOOT_IMAGE      = 2;
 static constexpr int DEX2OAT_FOR_FILTER          = 3;
 
-#define ANDROID_RUNTIME_APEX_BIN "/apex/com.android.runtime/bin"
+#define ANDROID_ART_APEX_BIN "/apex/com.android.art/bin"
 // Location of binaries in the Android Runtime APEX.
-static constexpr const char* kDex2oatPath = ANDROID_RUNTIME_APEX_BIN "/dex2oat";
-static constexpr const char* kDex2oatDebugPath = ANDROID_RUNTIME_APEX_BIN "/dex2oatd";
-static constexpr const char* kProfmanPath = ANDROID_RUNTIME_APEX_BIN "/profman";
-static constexpr const char* kProfmanDebugPath = ANDROID_RUNTIME_APEX_BIN "/profmand";
-static constexpr const char* kDexoptanalyzerPath = ANDROID_RUNTIME_APEX_BIN "/dexoptanalyzer";
-static constexpr const char* kDexoptanalyzerDebugPath = ANDROID_RUNTIME_APEX_BIN "/dexoptanalyzerd";
-#undef ANDROID_RUNTIME_APEX_BIN
+static constexpr const char* kDex2oatPath = ANDROID_ART_APEX_BIN "/dex2oat";
+static constexpr const char* kDex2oatDebugPath = ANDROID_ART_APEX_BIN "/dex2oatd";
+static constexpr const char* kProfmanPath = ANDROID_ART_APEX_BIN "/profman";
+static constexpr const char* kProfmanDebugPath = ANDROID_ART_APEX_BIN "/profmand";
+static constexpr const char* kDexoptanalyzerPath = ANDROID_ART_APEX_BIN "/dexoptanalyzer";
+static constexpr const char* kDexoptanalyzerDebugPath = ANDROID_ART_APEX_BIN "/dexoptanalyzerd";
+#undef ANDROID_ART_APEX_BIN
 
 // Clear the reference profile identified by the given profile name.
 bool clear_primary_reference_profile(const std::string& pkgname, const std::string& profile_name);
diff --git a/cmds/installd/otapreopt_chroot.cpp b/cmds/installd/otapreopt_chroot.cpp
index b4bcd53..3ff9d11 100644
--- a/cmds/installd/otapreopt_chroot.cpp
+++ b/cmds/installd/otapreopt_chroot.cpp
@@ -233,17 +233,17 @@
     }
 
     // Try to mount APEX packages in "/apex" in the chroot dir. We need at least
     // the Android Runtime APEX, as it is required by otapreopt to run dex2oat.
     std::vector<apex::ApexFile> active_packages = ActivateApexPackages();
 
     // Check that an Android Runtime APEX has been activated; clean up and exit
     // early otherwise.
     if (std::none_of(active_packages.begin(),
                      active_packages.end(),
                      [](const apex::ApexFile& package){
-                         return package.GetManifest().name() == "com.android.runtime";
+                         return package.GetManifest().name() == "com.android.art";
                      })) {
-        LOG(FATAL_WITHOUT_ABORT) << "No activated com.android.runtime APEX package.";
+        LOG(FATAL_WITHOUT_ABORT) << "No activated com.android.art APEX package.";
         DeactivateApexPackages(active_packages);
         exit(217);
     }
@@ -233,17 +233,17 @@
 
     // Try to mount APEX packages in "/apex" in the chroot dir. We need at least
-    // the Android Runtime APEX, as it is required by otapreopt to run dex2oat.
+    // the ART APEX, as it is required by otapreopt to run dex2oat.
     std::vector<apex::ApexFile> active_packages = ActivateApexPackages();
 
@@ -233,17 +233,17 @@
     std::vector<apex::ApexFile> active_packages = ActivateApexPackages();
 
-    // Check that an Android Runtime APEX has been activated; clean up and exit
+    // Check that an ART APEX has been activated; clean up and exit
     // early otherwise.
     if (std::none_of(active_packages.begin(),